package fr.lri.keller.td8correction;

import android.app.PendingIntent;
import android.appwidget.AppWidgetManager;
import android.appwidget.AppWidgetProvider;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.widget.RemoteViews;

/**
 * Implementation of App Widget functionality.
 */
public class TD8AppWidget extends AppWidgetProvider {

    // Action effectuée à chaque update (et donc entre autres, au démarrage de la tablette)
    @Override
    public void onUpdate(Context context, AppWidgetManager appWidgetManager, int[] appWidgetIds) {
        System.out.println("onUpdate");
        // There may be multiple widgets active, so update all of them
        final int N = appWidgetIds.length;
        for (int i = 0; i < N; i++) {
            updateAppWidget(context, appWidgetManager, appWidgetIds[i]);
        }
    }

    // À chaque update (et donc entre autres, au démarrage de la tablette), on :
    //  - associe le lancement de l'activité à un clic sur le widget
    //  - met à jour l'affichage des préférences
    static void updateAppWidget(Context context, AppWidgetManager appWidgetManager,
                                int appWidgetId) {
        RemoteViews views = new RemoteViews(context.getPackageName(), R.layout.td8_app_widget);

        // On associe le lancement de l'activité à un clic sur le widget
        Intent intent = new Intent(context, TD8Activity.class);
        PendingIntent pendingIntent = PendingIntent.getActivity(context, 0, intent, 0);
        views.setOnClickPendingIntent(R.id.root, pendingIntent);
        appWidgetManager.updateAppWidget(appWidgetId, views);

        // On met à jour l'affichage en fonction des préférences, de manière à ce que ça soit fait
        // peu de temps après le démarrage de la tablette par rafraîchissement
        SharedPreferences sharedPreferences = context.getSharedPreferences(TD8Activity.PREFERENCES, Context.MODE_PRIVATE);
        int score = sharedPreferences.getInt(TD8Activity.EXTRA_SCORE, 0);
        int level = sharedPreferences.getInt(TD8Activity.EXTRA_LEVEL, 1);
        maj(views, score, level);

        // On applique toutes ces modifications
        appWidgetManager.updateAppWidget(appWidgetId, views);
    }

    // Méthode métant à jour l'affichage
    private static void maj(RemoteViews views, int score, int level) {
        views.setTextViewText(R.id.textViewScore, "" + score);
        views.setTextViewText(R.id.textViewLevel, "" + level);
    }

    // Méthode appelée lorsqu'on reçoit un broadcast
    @Override
    public void onReceive(Context context, Intent intent) {
        super.onReceive(context, intent);

        // Si c'est un broadcast demandant de mettre à jour le score et le niveau
        if (intent.getAction().equals(TD8Activity.UPDATE_SCORE_LEVEL)) {
            // On récupère ce score et ce niveau
            int score = intent.getIntExtra(TD8Activity.EXTRA_SCORE, 0);
            int level = intent.getIntExtra(TD8Activity.EXTRA_LEVEL, 1);

            // Récupération des vues du widget : on n'a accès qu'à quelque chose de restreint
            // (RemoteViews) car ce n'est pas nous qui gérons directement l'interface du widget,
            // mais le bureau sur lequel il est
            RemoteViews views = new RemoteViews(context.getPackageName(), R.layout.td8_app_widget);

            // On modifie les zones du texte en fonction du score et du niveau (remplacer les ids
            // et les variables par ceux que vous aurez choisis) : on ne peut pas accéder
            // directement au vues avec RemoteViews, mais en contrepartie, on a des méthodes
            // effectuant les modifications sur les vues
            maj(views, score, level);

            // On lance la mise à jour du widget
            AppWidgetManager appWidgetManager = AppWidgetManager.getInstance(context);
            ComponentName watchWidget = new ComponentName(context, TD8AppWidget.class);
            appWidgetManager.updateAppWidget(watchWidget, views);
        }
    }
}